# -*- coding: utf-8 -*-

__pkg__ = 'Flask-Feather'
__url__ = 'https://github.com/thetomcat/Flask-Feather'
__info__ = 'Insert feather icons into jinja2 templates'
__author__ = 'Tom Vos'
__email__ = 'tjvos1@gmail.com'
__version__ = '0.0.5'

from .extension import Feather